@@ -8,11 +8,11 @@ App::Tel - A script for logging into devices
 
 =head1 VERSION
 
-0.2015_04
+0.2015_05
 
 =cut
 
-our $VERSION = eval  { 0.2015_04 };
+our $VERSION = eval  { 0.2015_05 };
 
 
 =head1 SYNOPSIS
@@ -45,11 +45,12 @@ use v5.10;
 
 my $sleeper;
 
-sub mysleep(;@) { sleep }
+# prototype required to avoid prototype mismatch warning
+sub mysleep (;@) { sleep }
 
 BEGIN {
-    if (eval 'require Time::HiRes') {
-        import Time::HiRes qw(sleep);
+    if (eval { require Time::HiRes }) {
+        Time::HiRes->import( qw(sleep) );
         $sleeper = \&Time::HiRes::sleep;
     }
 }
